@@ -5,7 +5,7 @@ use Carp;
 use SOAP::WSDL::TypeLookup;
 use base qw(SOAP::WSDL::Expat::Base);
 
-use version; our $VERSION = qv('2.00.02');
+use version; our $VERSION = qv('2.00.03');
 
 sub _import_children {
     my ($self, $name, $imported, $importer, $import_namespace) = @_;
@@ -310,11 +310,11 @@ the same terms as perl itself
 
 =head1 Repository information
 
- $Id: WSDLParser.pm 672 2008-05-16 09:37:59Z kutterma $
+ $Id: WSDLParser.pm 677 2008-05-18 20:17:56Z kutterma $
 
- $LastChangedDate: 2008-05-16 11:37:59 +0200 (Fr, 16 Mai 2008) $
- $LastChangedRevision: 672 $
+ $LastChangedDate: 2008-05-18 22:17:56 +0200 (So, 18 Mai 2008) $
+ $LastChangedRevision: 677 $
  $LastChangedBy: kutterma $
 
- $HeadURL: https://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Expat/WSDLParser.pm $
+ $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Expat/WSDLParser.pm $
 
