@@ -3,7 +3,7 @@ package SOAP::WSDL::XSD::Typelib::Element;
 use Class::Std::Fast::Storable constructor => 'none';
 use strict;
 
-use version; our $VERSION = qv('2.00.02');
+use version; our $VERSION = qv('2.00.03');
 
 my %NAME;
 my %NILLABLE;
@@ -176,10 +176,10 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 672 $
+ $Rev: 677 $
  $LastChangedBy: kutterma $
- $Id: Element.pm 672 2008-05-16 09:37:59Z kutterma $
- $HeadURL: https://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/XSD/Typelib/Element.pm $
+ $Id: Element.pm 677 2008-05-18 20:17:56Z kutterma $
+ $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/XSD/Typelib/Element.pm $
 
 =cut
 
